@@ -140,7 +140,7 @@ apply_d_change_link(core::Download* download, const torrent::Object::list_type&
   case 0:
     if (symlink(target.c_str(), link.c_str()) == -1){
       lt_log_print(torrent::LOG_TORRENT_WARN, "create_link failed: %s",
-          rak::error_number::current().c_str());
+                   rak::error_number::current().c_str());
     }
     break;
 
@@ -324,7 +324,7 @@ struct call_add_d_peer_t {
 
   void operator() (const sockaddr* sa, int err) {
     if (sa == NULL) {
-      lt_log_print(torrent::LOG_CONNECTION_WARN, "Could not resolve hostname for added peer.");
+      lt_log_print(torrent::LOG_TORRENT_WARN, "could not resolve hostname for added peer");
     } else {
       m_download->download()->add_peer(sa, m_port);
     }
@@ -593,8 +593,7 @@ d_list_push_back_unique(core::Download* download, const torrent::Object& rawArgs
   const torrent::Object& args = (rawArgs.is_list() && !rawArgs.as_list().empty()) ? rawArgs.as_list().front() : rawArgs;
   torrent::Object::list_type& list = download_get_variable(download, first_key, second_key).as_list();
 
-  if (std::find_if(list.begin(), list.end(),
-                   rak::bind1st(std::ptr_fun(&torrent::object_equal), args)) == list.end())
+  if (std::find_if(list.begin(), list.end(), [args](const torrent::Object& obj) { return torrent::object_equal(obj, args); }) == list.end())
     list.push_back(rawArgs);
 
   return torrent::Object();
@@ -605,8 +604,7 @@ d_list_has(core::Download* download, const torrent::Object& rawArgs, const char*
   const torrent::Object& args = (rawArgs.is_list() && !rawArgs.as_list().empty()) ? rawArgs.as_list().front() : rawArgs;
   torrent::Object::list_type& list = download_get_variable(download, first_key, second_key).as_list();
 
-  return (int64_t)(std::find_if(list.begin(), list.end(),
-                                rak::bind1st(std::ptr_fun(&torrent::object_equal), args)) != list.end());
+  return (int64_t)(std::find_if(list.begin(), list.end(), [args](const torrent::Object& obj) { return torrent::object_equal(obj, args); }) != list.end());
 }
 
 torrent::Object
@@ -614,7 +612,7 @@ d_list_remove(core::Download* download, const torrent::Object& rawArgs, const ch
   const torrent::Object& args = (rawArgs.is_list() && !rawArgs.as_list().empty()) ? rawArgs.as_list().front() : rawArgs;
   torrent::Object::list_type& list = download_get_variable(download, first_key, second_key).as_list();
 
-  list.erase(std::remove_if(list.begin(), list.end(), rak::bind1st(std::ptr_fun(&torrent::object_equal), args)), list.end());
+  list.erase(std::remove_if(list.begin(), list.end(), [args](const torrent::Object& obj) { return torrent::object_equal(obj, args); }), list.end());
 
   return torrent::Object();
 }
@@ -872,8 +870,10 @@ initialize_command_download() {
 
   CMD2_DL         ("d.wanted_chunks",    CMD2_ON_DATA(wanted_chunks));
 
-  CMD2_DL_V       ("d.tracker_announce",     std::bind(&torrent::Download::manual_request, CMD2_BIND_DL, false)); 
-  CMD2_DL_V       ("d.tracker_announce.force", std::bind(&torrent::Download::manual_request, CMD2_BIND_DL, true));
+  // Do not exposre d.tracker_announce.force to regular users.
+  CMD2_DL_V       ("d.tracker_announce",       std::bind(&torrent::Download::manual_request, CMD2_BIND_DL, false)); 
+  CMD2_DL_V       ("d.tracker_announce.force", std::bind(&torrent::Download::manual_request, CMD2_BIND_DL, true)); 
+
   CMD2_DL         ("d.tracker_numwant",      std::bind(&torrent::TrackerList::numwant, CMD2_BIND_TL));
   CMD2_DL_VALUE_V ("d.tracker_numwant.set",  std::bind(&torrent::TrackerList::set_numwant, CMD2_BIND_TL, std::placeholders::_2));
   // TODO: Deprecate 'd.tracker_focus'.
@@ -903,7 +903,7 @@ initialize_command_download() {
   //                                           CG_GROUP_INDEX()));
 
   CMD2_DL         ("d.group",      std::bind(&cg_d_group, std::placeholders::_1));
-  CMD2_DL         ("d.group.name", std::bind(&cg_d_group, std::placeholders::_1));
+  CMD2_DL         ("d.group.name", std::bind(&cg_d_group_name, std::placeholders::_1));
   CMD2_DL_V       ("d.group.set",  std::bind(&cg_d_group_set, std::placeholders::_1, std::placeholders::_2));
 
   CMD2_DL_LIST    ("f.multicall", std::bind(&f_multicall, std::placeholders::_1, std::placeholders::_2));
