@@ -5,12 +5,12 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -40,25 +40,24 @@
 #include <torrent/utils/log.h>
 #include <torrent/utils/option_strings.h>
 
-#include "globals.h"
-#include "control.h"
 #include "command_helpers.h"
+#include "control.h"
+#include "globals.h"
 #include "rpc/parse.h"
 #include "rpc/parse_options.h"
 
 static std::vector<std::pair<const char*, int>> object_storage_flags = {
-  { "multi", rpc::object_storage::flag_multi_type },
-  { "simple", rpc::object_storage::flag_function_type },
-  { "value", rpc::object_storage::flag_value_type },
-  { "bool", rpc::object_storage::flag_bool_type },
-  { "string", rpc::object_storage::flag_string_type },
-  { "list", rpc::object_storage::flag_list_type },
+  {"multi", rpc::object_storage::flag_multi_type},
+  {"simple", rpc::object_storage::flag_function_type},
+  {"value", rpc::object_storage::flag_value_type},
+  {"bool", rpc::object_storage::flag_bool_type},
+  {"string", rpc::object_storage::flag_string_type},
+  {"list", rpc::object_storage::flag_list_type},
 
-  { "static", rpc::object_storage::flag_static },
-  { "private", rpc::object_storage::flag_private },
-  { "const", rpc::object_storage::flag_constant },
-  { "rlookup", rpc::object_storage::flag_rlookup }
-};
+  {"static", rpc::object_storage::flag_static},
+  {"private", rpc::object_storage::flag_private},
+  {"const", rpc::object_storage::flag_constant},
+  {"rlookup", rpc::object_storage::flag_rlookup}};
 
 static int
 object_storage_parse_flag(const std::string& flag) {
@@ -109,7 +108,7 @@ system_method_generate_command2(torrent::Object* object, torrent::Object::list_c
   if (first + 1 == last) {
     if (!first->is_dict_key())
       throw torrent::input_error("New command of wrong type.");
-    
+
     *object = *first;
 
     uint32_t flags = object->flags() & torrent::Object::mask_function;
@@ -122,9 +121,9 @@ system_method_generate_command2(torrent::Object* object, torrent::Object::list_c
     while (first != last) {
       if (!first->is_dict_key())
         throw torrent::input_error("New command of wrong type.");
-      
+
       object->as_list().push_back(*first++);
-      
+
       uint32_t flags = object->as_list().back().flags() & torrent::Object::mask_function;
       object->as_list().back().unset_flags(torrent::Object::mask_function);
       object->as_list().back().set_flags((flags >> 1) & torrent::Object::mask_function);
@@ -134,20 +133,32 @@ system_method_generate_command2(torrent::Object* object, torrent::Object::list_c
 
 // torrent::Object
 // system_method_insert_function(const torrent::Object::list_type& args, int flags) {
-  
+
 // }
 
+// This is only used by tinyxml2, xmlrpc-c intercepts the call internally
+torrent::Object
+system_listMethods() {
+  torrent::Object resultRaw = torrent::Object::create_list();
+  torrent::Object::list_type& result = resultRaw.as_list();
+  result.push_back("system.multicall"); // Handled directly by the XMLRPC code
+  for (auto itr : rpc::commands) {
+    result.push_back(itr.first);
+  }
+  return resultRaw;
+}
+
 torrent::Object
 system_method_insert_object(const torrent::Object::list_type& args, int flags) {
   if (args.empty())
     throw torrent::input_error("Invalid argument count.");
 
   torrent::Object::list_const_iterator itrArgs = args.begin();
-  const std::string& rawKey = (itrArgs++)->as_string();
+  const std::string&                   raw_key = (itrArgs++)->as_string();
 
-  if (rawKey.empty() ||
-      control->object_storage()->find_raw_string(torrent::raw_string::from_string(rawKey)) != control->object_storage()->end() ||
-      rpc::commands.has(rawKey) || rpc::commands.has(rawKey + ".set"))
+  if (raw_key.empty() ||
+      control->object_storage()->find_raw_string(torrent::raw_string::from_string(raw_key)) != control->object_storage()->end() ||
+      rpc::commands.has(raw_key) || rpc::commands.has(raw_key + ".set"))
     throw torrent::input_error("Invalid key.");
 
   torrent::Object value;
@@ -171,8 +182,7 @@ system_method_insert_object(const torrent::Object::list_type& args, int flags) {
     throw torrent::input_error("Invalid type.");
   }
 
-  // We must initialize this varriable to prevent a critical memory leak
-  int cmd_flags = rpc::CommandMap::flag_delete_key;
+  int cmd_flags = 0;
 
   if (!(flags & rpc::object_storage::flag_static))
     cmd_flags |= rpc::CommandMap::flag_modifiable;
@@ -180,81 +190,93 @@ system_method_insert_object(const torrent::Object::list_type& args, int flags) {
     cmd_flags |= rpc::CommandMap::flag_public_xmlrpc;
 
   if ((flags & rpc::object_storage::mask_type) == rpc::object_storage::flag_list_type) {
-    torrent::Object valueList = torrent::Object::create_list();
+    torrent::Object             valueList     = torrent::Object::create_list();
     torrent::Object::list_type& valueListType = valueList.as_list();
 
     if ((itrArgs)->is_list())
       valueListType = (itrArgs)->as_list();
 
-    control->object_storage()->insert_str(rawKey, valueList, flags);
+    control->object_storage()->insert_str(raw_key, valueList, flags);
   } else {
-    control->object_storage()->insert_str(rawKey, value, flags);
+    control->object_storage()->insert_str(raw_key, value, flags);
   }
 
   if ((flags & rpc::object_storage::mask_type) == rpc::object_storage::flag_function_type ||
       (flags & rpc::object_storage::mask_type) == rpc::object_storage::flag_multi_type) {
 
-    rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call<rpc::target_type> >::type>
-      (create_new_key(rawKey),
-       std::bind(&rpc::object_storage::call_function_str, control->object_storage(),
-                 rawKey, std::placeholders::_1, std::placeholders::_2),
-       &rpc::command_base_call<rpc::target_type>,
-       cmd_flags, NULL, NULL);
+    rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call<rpc::target_type>>::type>(
+      raw_key,
+      std::bind(&rpc::object_storage::call_function_str, control->object_storage(), raw_key, std::placeholders::_1, std::placeholders::_2),
+      &rpc::command_base_call<rpc::target_type>,
+      cmd_flags,
+      NULL,
+      NULL);
 
   } else {
-    rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call<rpc::target_type> >::type>
-      (create_new_key(rawKey),
-       std::bind(&rpc::object_storage::get_str, control->object_storage(), rawKey),
-       &rpc::command_base_call<rpc::target_type>,
-       cmd_flags, NULL, NULL);
+    rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call<rpc::target_type>>::type>(
+      raw_key,
+      std::bind(&rpc::object_storage::get_str, control->object_storage(), raw_key),
+      &rpc::command_base_call<rpc::target_type>,
+      cmd_flags,
+      NULL,
+      NULL);
   }
 
   // Not the right argument.
   // if (flags & rpc::object_storage::flag_rlookup) {
   //   rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_string<rpc::target_type> >::type>
-  //     (create_new_key<9>(rawKey, ".rlookup"),
-  //      std::bind(&rpc::object_storage::rlookup_obj_list, control->object_storage(), rawKey),
+  //     (create_new_key<9>(raw_key, ".rlookup"),
+  //      std::bind(&rpc::object_storage::rlookup_obj_list, control->object_storage(), raw_key),
   //      &rpc::command_base_call_string<rpc::target_type>,
   //      cmd_flags, NULL, NULL);
   // }
 
   // TODO: Next... Make test class for this.
 
-//   // Ehm... no proper handling if these throw.
+  //   // Ehm... no proper handling if these throw.
 
   if (!(flags & rpc::object_storage::flag_constant)) {
     switch (flags & rpc::object_storage::mask_type) {
     case rpc::object_storage::flag_bool_type:
-      rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_value<rpc::target_type> >::type>
-        (create_new_key<5>(rawKey, ".set"),
-         std::bind(&rpc::object_storage::set_str_bool, control->object_storage(), rawKey, std::placeholders::_2),
-         &rpc::command_base_call_value<rpc::target_type>,
-         cmd_flags, NULL, NULL);
+      rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_value<rpc::target_type>>::type>(
+        raw_key + ".set",
+        std::bind(&rpc::object_storage::set_str_bool, control->object_storage(), raw_key, std::placeholders::_2),
+        &rpc::command_base_call_value<rpc::target_type>,
+        cmd_flags,
+        NULL,
+        NULL);
       break;
     case rpc::object_storage::flag_value_type:
-      rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_value<rpc::target_type> >::type>
-        (create_new_key<5>(rawKey, ".set"),
-         std::bind(&rpc::object_storage::set_str_value, control->object_storage(), rawKey, std::placeholders::_2),
-         &rpc::command_base_call_value<rpc::target_type>,
-         cmd_flags, NULL, NULL);
+      rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_value<rpc::target_type>>::type>(
+        raw_key + ".set",
+        std::bind(&rpc::object_storage::set_str_value, control->object_storage(), raw_key, std::placeholders::_2),
+        &rpc::command_base_call_value<rpc::target_type>,
+        cmd_flags,
+        NULL,
+        NULL);
       break;
     case rpc::object_storage::flag_string_type:
-      rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_string<rpc::target_type> >::type>
-        (create_new_key<5>(rawKey, ".set"),
-         std::bind(&rpc::object_storage::set_str_string, control->object_storage(), rawKey, std::placeholders::_2),
-         &rpc::command_base_call_string<rpc::target_type>,
-         cmd_flags, NULL, NULL);
+      rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_string<rpc::target_type>>::type>(
+        raw_key + ".set",
+        std::bind(&rpc::object_storage::set_str_string, control->object_storage(), raw_key, std::placeholders::_2),
+        &rpc::command_base_call_string<rpc::target_type>,
+        cmd_flags,
+        NULL,
+        NULL);
       break;
     case rpc::object_storage::flag_list_type:
-      rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_list<rpc::target_type> >::type>
-        (create_new_key<5>(rawKey, ".set"),
-         std::bind(&rpc::object_storage::set_str_list, control->object_storage(), rawKey, std::placeholders::_2),
-         &rpc::command_base_call_list<rpc::target_type>,
-         cmd_flags, NULL, NULL);
+      rpc::commands.insert_slot<rpc::command_base_is_type<rpc::command_base_call_list<rpc::target_type>>::type>(
+        raw_key + ".set",
+        std::bind(&rpc::object_storage::set_str_list, control->object_storage(), raw_key, std::placeholders::_2),
+        &rpc::command_base_call_list<rpc::target_type>,
+        cmd_flags,
+        NULL,
+        NULL);
       break;
     case rpc::object_storage::flag_function_type:
     case rpc::object_storage::flag_multi_type:
-    default: break;
+    default:
+      break;
     }
   }
 
@@ -282,22 +304,15 @@ system_method_insert(const torrent::Object::list_type& args) {
     throw torrent::input_error("Invalid argument count.");
 
   torrent::Object::list_const_iterator itrArgs = args.begin();
-  const std::string& rawKey = (itrArgs++)->as_string();
+  const std::string&                   raw_key  = (itrArgs++)->as_string();
 
-  if (rawKey.empty() || rpc::commands.has(rawKey))
+  if (raw_key.empty() || rpc::commands.has(raw_key))
     throw torrent::input_error("Invalid key.");
 
-  int flags = rpc::CommandMap::flag_delete_key | rpc::CommandMap::flag_modifiable | rpc::CommandMap::flag_public_xmlrpc;
   int new_flags = rpc::parse_option_flags(itrArgs->as_string(), std::bind(&object_storage_parse_flag, std::placeholders::_1));
 
-  if ((new_flags & rpc::object_storage::flag_private))
-    flags &= ~rpc::CommandMap::flag_public_xmlrpc;
-
-  if ((new_flags & rpc::object_storage::flag_constant))
-    flags &= ~rpc::CommandMap::flag_modifiable;
-
   torrent::Object::list_type new_args;
-  new_args.push_back(rawKey);
+  new_args.push_back(raw_key);
 
   if ((new_flags & rpc::object_storage::flag_function_type) ||
       (new_flags & rpc::object_storage::flag_multi_type)) {
@@ -345,8 +360,7 @@ system_method_redirect(const torrent::Object::list_type& args) {
   std::string new_key  = torrent::object_create_string(args.front());
   std::string dest_key = torrent::object_create_string(args.back());
 
-  rpc::commands.create_redirect(create_new_key(new_key), create_new_key(dest_key),
-                                rpc::CommandMap::flag_public_xmlrpc | rpc::CommandMap::flag_delete_key | rpc::CommandMap::flag_modifiable);
+  rpc::commands.create_redirect(new_key, dest_key, rpc::CommandMap::flag_public_xmlrpc | rpc::CommandMap::flag_modifiable);
 
   return torrent::Object();
 }
@@ -372,9 +386,9 @@ system_method_has_key(const torrent::Object::list_type& args) {
     throw torrent::input_error("Invalid argument count.");
 
   torrent::Object::list_const_iterator itrArgs = args.begin();
-  const std::string& key = (itrArgs++)->as_string();
-  const std::string& cmd_key = (itrArgs++)->as_string();
-  
+  const std::string&                   key     = (itrArgs++)->as_string();
+  const std::string&                   cmd_key = (itrArgs++)->as_string();
+
   return control->object_storage()->has_str_multi_key(key, cmd_key);
 }
 
@@ -384,9 +398,9 @@ system_method_set_key(const torrent::Object::list_type& args) {
     throw torrent::input_error("Invalid argument count.");
 
   torrent::Object::list_const_iterator itrArgs = args.begin();
-  const std::string& key = (itrArgs++)->as_string();
-  const std::string& cmd_key = (itrArgs++)->as_string();
-  
+  const std::string&                   key     = (itrArgs++)->as_string();
+  const std::string&                   cmd_key = (itrArgs++)->as_string();
+
   if (itrArgs == args.end()) {
     control->object_storage()->erase_str_multi_key(key, cmd_key);
     return torrent::Object();
@@ -403,9 +417,9 @@ system_method_set_key(const torrent::Object::list_type& args) {
 torrent::Object
 system_method_list_keys(const torrent::Object::string_type& args) {
   const torrent::Object::map_type& multi_cmd = control->object_storage()->get_str(args).as_map();
-  
-  torrent::Object rawResult = torrent::Object::create_list();
-  torrent::Object::list_type& result = rawResult.as_list();
+
+  torrent::Object                  rawResult = torrent::Object::create_list();
+  torrent::Object::list_type&      result    = rawResult.as_list();
 
   for (torrent::Object::map_const_iterator itr = multi_cmd.begin(), last = multi_cmd.end(); itr != last; itr++)
     result.push_back(itr->first);
@@ -428,6 +442,11 @@ cmd_catch(rpc::target_type target, const torrent::Object& args) {
 
 void
 initialize_command_dynamic() {
+  // clang-format off
+  #ifdef HAVE_XMLRPC_TINYXML2
+  CMD2_ANY         ("system.listMethods", std::bind(&system_listMethods)); // only used by tinyxml2
+  #endif
+
   CMD2_VAR_BOOL    ("method.use_deprecated", true);
   CMD2_VAR_VALUE   ("method.use_intermediate", 1);
 
@@ -472,4 +491,5 @@ initialize_command_dynamic() {
   CMD2_ANY         ("strings.log_group",                 std::bind(&torrent::option_list_strings, torrent::OPTION_LOG_GROUP));
   CMD2_ANY         ("strings.tracker_event",             std::bind(&torrent::option_list_strings, torrent::OPTION_TRACKER_EVENT));
   CMD2_ANY         ("strings.tracker_mode",              std::bind(&torrent::option_list_strings, torrent::OPTION_TRACKER_MODE));
+  // clang-format on
 }
