@@ -148,12 +148,12 @@ void initialize_commands();
   rpc::commands.create_redirect(from_key, to_key, rpc::CommandMap::flag_public_xmlrpc | rpc::CommandMap::flag_tracker_target | rpc::CommandMap::flag_dont_delete);
 
 #define CMD2_REDIRECT_GENERIC_STR(from_key, to_key)                     \
-  rpc::commands.create_redirect(create_new_key(from_key), create_new_key(to_key), \
-                                rpc::CommandMap::flag_public_xmlrpc | rpc::CommandMap::flag_no_target | rpc::CommandMap::flag_delete_key);
+  rpc::commands.create_redirect(from_key, to_key, \
+                                rpc::CommandMap::flag_public_xmlrpc | rpc::CommandMap::flag_no_target);
 
 #define CMD2_REDIRECT_GENERIC_STR_NO_EXPORT(from_key, to_key)                     \
-  rpc::commands.create_redirect(create_new_key(from_key), create_new_key(to_key), \
-                                rpc::CommandMap::flag_no_target | rpc::CommandMap::flag_delete_key);
+  rpc::commands.create_redirect(from_key, to_key, \
+                                rpc::CommandMap::flag_no_target);
 
 //
 // Conversion of return types:
@@ -188,24 +188,4 @@ template <typename T>
 object_convert_type<T, void>
 object_convert_void(T f) { return f; }
 
-//
-// Key creation:
-//
-
-template <int postfix_size>
-inline const char*
-create_new_key(const std::string& key, const char postfix[postfix_size]) {
-  char *buffer = new char[key.size() + std::max(postfix_size, 1)];
-  std::memcpy(buffer, key.c_str(), key.size() + 1);
-  std::memcpy(buffer + key.size(), postfix, postfix_size);
-  return buffer;
-}
-
-inline const char*
-create_new_key(const std::string& key) {
-  char *buffer = new char[key.size() + 1];
-  std::memcpy(buffer, key.c_str(), key.size() + 1);
-  return buffer;
-}
-
 #endif
