@@ -41,10 +41,11 @@
 #ifndef RTORRENT_CORE_DOWNLOAD_FACTORY_H
 #define RTORRENT_CORE_DOWNLOAD_FACTORY_H
 
+#include <functional>
 #include <iosfwd>
+
 #include <rak/priority_queue_default.h>
 #include <torrent/object.h>
-#include lt_tr1_functional
 
 #include "http_queue.h"
 
@@ -77,6 +78,9 @@ public:
   bool                get_start() const     { return m_start; }
   void                set_start(bool v)     { m_start = v; }
 
+  bool                get_init_load() const { return m_initLoad; }
+  void                set_init_load(bool v) { m_initLoad = v; }
+
   bool                print_log() const     { return m_printLog; }
   void                set_print_log(bool v) { m_printLog = v; }
 
@@ -105,6 +109,7 @@ private:
   bool                m_start;
   bool                m_printLog;
   bool                m_isFile;
+  bool                m_initLoad;
 
   command_list_type         m_commands;
   torrent::Object::map_type m_variables;
