@@ -1,47 +1,13 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef RTORRENT_CORE_MANAGER_H
 #define RTORRENT_CORE_MANAGER_H
 
 #include <iosfwd>
+#include <memory>
 #include <vector>
 
 #include <torrent/utils/log_buffer.h>
 #include <torrent/connection_manager.h>
+#include <torrent/object.h>
 
 #include "download_list.h"
 #include "poll_manager.h"
@@ -85,12 +51,14 @@ public:
   View*               hashing_view()                      { return m_hashingView; }
   void                set_hashing_view(View* v);
 
-  torrent::log_buffer* log_important()                    { return m_log_important; }
-  torrent::log_buffer* log_complete()                     { return m_log_complete; }
+  torrent::log_buffer* log_important()                    { return m_log_important.get(); }
+  torrent::log_buffer* log_complete()                     { return m_log_complete.get(); }
 
   ThrottleMap&          throttles()                       { return m_throttles; }
   torrent::ThrottlePair get_throttle(const std::string& name);
 
+  int64_t             retrieve_throttle_value(const torrent::Object::string_type& name, bool rate, bool up);
+
   // Use custom throttle for the given range of IP addresses.
   void                  set_address_throttle(uint32_t begin, uint32_t end, torrent::ThrottlePair throttles);
   torrent::ThrottlePair get_address_throttle(const sockaddr* addr);
@@ -152,8 +120,8 @@ private:
   ThrottleMap         m_throttles;
   AddressThrottleMap  m_addressThrottles;
 
-  torrent::log_buffer* m_log_important;
-  torrent::log_buffer* m_log_complete;
+  torrent::log_buffer_ptr m_log_important;
+  torrent::log_buffer_ptr m_log_complete;
 };
 
 // Meh, cleanup.
