@@ -37,8 +37,8 @@
 #ifndef RTORRENT_INPUT_BINDINGS_H
 #define RTORRENT_INPUT_BINDINGS_H
 
+#include <functional>
 #include <map>
-#include lt_tr1_functional
 
 #include "display/attributes.h"
 
