@@ -53,7 +53,7 @@
 #include <rak/functional.h>
 #include <rak/error_number.h>
 
-#ifdef USE_EXECINFO
+#ifdef HAVE_BACKTRACE
 #include <execinfo.h>
 #endif
 
@@ -81,6 +81,9 @@
 
 #include "thread_worker.h"
 
+#define LT_LOG(log_fmt, ...)                                    \
+  lt_log_print(torrent::LOG_SYSTEM, "system: " log_fmt, __VA_ARGS__);
+
 void handle_sigbus(int signum, siginfo_t* sa, void* ptr);
 void do_panic(int signum);
 void print_help();
@@ -132,8 +135,9 @@ load_session_torrents() {
 
     // Replace with session torrent flag.
     f->set_session(true);
+    f->set_init_load(true);
     f->slot_finished(std::bind(&rak::call_delete_func<core::DownloadFactory>, f));
-    f->load(entries.path() + first->d_name);
+    f->load(entries.path() + first->s_name);
     f->commit();
   }
 }
@@ -146,6 +150,7 @@ load_arg_torrents(char** first, char** last) {
 
     // Replace with session torrent flag.
     f->set_start(true);
+    f->set_init_load(true);
     f->slot_finished(std::bind(&rak::call_delete_func<core::DownloadFactory>, f));
     f->load(*first);
     f->commit();
@@ -466,6 +471,8 @@ main(int argc, char** argv) {
       }
     }
 
+    LT_LOG("seeded srandom and srand48 (seed:%u)", random_seed);
+
     control->initialize();
     control->ui()->load_input_history();
 
@@ -528,7 +535,7 @@ handle_sigbus(int signum, siginfo_t* sa, void* ptr) {
   std::stringstream output;
   output << "Caught SIGBUS, dumping stack:" << std::endl;
 
-#ifdef USE_EXECINFO
+#ifdef HAVE_BACKTRACE
   void* stackPtrs[20];
 
   // Print the stack and exit.
@@ -599,7 +606,7 @@ do_panic(int signum) {
 
   output << "Caught " << SignalHandler::as_string(signum) << ", dumping stack:" << std::endl;
   
-#ifdef USE_EXECINFO
+#ifdef HAVE_BACKTRACE
   void* stackPtrs[20];
 
   // Print the stack and exit.
@@ -668,7 +675,7 @@ print_help() {
   std::cout << "  o                 View trackers" << std::endl;
   std::cout << std::endl;
 
-  std::cout << "Report bugs to <sundell.software@gmail.com>." << std::endl;
+  std::cout << "Report bugs to <github.com/rakshasa/rtorrent>." << std::endl;
 
   exit(0);
 }
