@@ -1,48 +1,8 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef RTORRENT_RPC_COMMAND_H
 #define RTORRENT_RPC_COMMAND_H
 
 #include <functional>
 #include <limits>
-#include <inttypes.h>
-#include <torrent/object.h>
-#include lt_tr1_functional
-
 #include <torrent/object.h>
 #include <torrent/data/file_list_iterator.h>
 
@@ -62,7 +22,7 @@ namespace rpc {
 
 template <typename Target>
 struct target_wrapper {
-  typedef Target      target_type; 
+  typedef Target      target_type;
   typedef Target      cleaned_type;
 };
 
@@ -70,7 +30,7 @@ template <>
 struct target_wrapper<void> {
   struct no_type {};
 
-  typedef void        target_type; 
+  typedef void        target_type;
   typedef no_type*    cleaned_type;
 };
 
@@ -148,10 +108,10 @@ public:
   struct stack_type {
     torrent::Object*       begin() { return reinterpret_cast<torrent::Object*>(buffer); }
     torrent::Object*       end()   { return reinterpret_cast<torrent::Object*>(buffer) + max_arguments; }
-    
+
     const torrent::Object* begin() const { return reinterpret_cast<const torrent::Object*>(buffer); }
     const torrent::Object* end()   const { return reinterpret_cast<const torrent::Object*>(buffer) + max_arguments; }
-    
+
     torrent::Object&       operator [] (unsigned int idx)       { return *(begin() + idx); }
     const torrent::Object& operator [] (unsigned int idx) const { return *(begin() + idx); }
 
