@@ -37,6 +37,7 @@
 #ifndef RTORRENT_UTILS_THREAD_BASE_H
 #define RTORRENT_UTILS_THREAD_BASE_H
 
+#include <memory>
 #include <pthread.h>
 #include <sys/types.h>
 #include <torrent/utils/thread_base.h>
@@ -66,14 +67,6 @@ public:
 
   void                queue_item(thread_base_func newFunc);
 
-  // Only call this when global lock has been acquired, as it checks
-  // ThreadBase::is_main_polling() which is only guaranteed to remain
-  // 'false' if global lock keeps main thread from entering polling
-  // again.
-  //
-  // Move to libtorrent some day.
-  static void         interrupt_main_polling();
-
 protected:
   int64_t             next_timeout_usec();
 
@@ -90,7 +83,7 @@ protected:
 
   // Temporary hack to pass messages to a thread. This really needs to
   // be cleaned up and/or integrated into the priority queue itself.
-  thread_queue_hack*  m_threadQueue;
+  std::unique_ptr<thread_queue_hack>  m_threadQueue;
 };
 
 #endif
